aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py18
1 files changed, 8 insertions, 10 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py b/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py
index 4a2987ea..d3a15279 100644
--- a/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_auto_batch.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -16,24 +16,22 @@ import re # noqa: F401
import six
-from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_openapi_client.models.fileset_entity import FilesetEntity # noqa: F401,E501
-
class FilesetAutoBatch(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'editgroup': 'Editgroup',
'entity_list': 'list[FilesetEntity]'
}
@@ -44,7 +42,7 @@ class FilesetAutoBatch(object):
}
def __init__(self, editgroup=None, entity_list=None): # noqa: E501
- """FilesetAutoBatch - a model defined in Swagger""" # noqa: E501
+ """FilesetAutoBatch - a model defined in OpenAPI""" # noqa: E501
self._editgroup = None
self._entity_list = None
@@ -103,7 +101,7 @@ class FilesetAutoBatch(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -16,24 +16,22 @@ import re # noqa: F401
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name